@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2013-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2013-2015 -- leonerd@leonerd.org.uk
 
 package Tickit::Widget::GridBox;
 
@@ -10,7 +10,7 @@ use warnings;
 use base qw( Tickit::ContainerWidget );
 use Tickit::Style;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 use Carp;
 
@@ -106,7 +106,7 @@ sub new
    my $self = $class->SUPER::new( %args );
 
    $self->{grid} = [];
-   $self->{max_col} = 0;
+   $self->{max_col} = -1;
 
    if( my $children = $args{children} ) {
       foreach my $row ( 0 .. $#$children ) {
@@ -357,8 +357,8 @@ sub insert_col
    my $grid = $self->{grid};
    $self->{max_col}++;
 
-   foreach my $row ( 0 .. $self->rowcount - 1 ) {
-      splice @{ $grid->[$row] }, $col, 0, ( undef );
+   foreach my $row ( 0 .. max( $self->rowcount, scalar @$children ) - 1 ) {
+      splice @{ $grid->[$row] //= [ ( undef ) x $col ] }, $col, 0, ( undef );
 
       next unless my $child = $children->[$row];
 
